
*======================================
*	Talking Behind: Data Analysis
*======================================


*--------------------------------------
*-> Figure 2 Time Path
*--------------------------------------
		
		use "/Users/ludong/Dropbox/TalkBehindData/data.dta", clear
		replace majority = 1 if treatment == "GMBase"
		
		gen count = 1
		collapse y = contribution, by(period treat_main majority)
		
		global linestyle "lcolor(black) mcolor(black)  msize(large) lwidth(medium) "
		twoway (connect y period if majority == 1, m(S) lpattern(solid) $linestyle )	///
				(connect y period if majority == 0, m(Th) lpattern(dash) $linestyle )	///
				, by(treat_main, note("") col(4)) caption(`caption1', size(`size1') pos(6)) note(`note',ring(0) pos(12) nobox) name(g1,replace)   ///
				xtitle("Round", size(`size')) ytitle("Average Investment", size(`size'))  ///
				xlabel(1(1)8, labsize(`size') ) ylabel(0(2)10, labsize(`size') angle(0)) ///
				legend(lab(1 "Partners") lab(2 "Lone Persons") size(`size')  ///
				col(2) ring(0) pos(3) region(lcolor(none) fcolor(none))) scheme(s1mono) ysize(2.5)
		//Manually adjust the figure for aesthetics
		

		
*-------------------------------------------------------
*-> Figure 3 Distribution of the loner's investment
*-------------------------------------------------------
		
		use "/Users/ludong/Dropbox/TalkBehindData/data.dta", clear
		 
		replace partner = 0 if treatment == "GMBase"
		keep if partner == 0
		
		gen count = 1
		collapse (count) count, by(treat_main contribution)
		bys treat_main: egen var1 = total(count)
		gen freq = count/var1
		gen x = contribution
		
		
		twoway (bar freq x if contribution == 0, col(red)) ///
			(bar freq x if contribution > 0 & contribution < 10, col(eltblue)) ///
			(bar freq x if contribution == 10, col(black)), ///
			by(treat_main, col(4) legend(off)) ///
			ytitle("Percent",size(med)) ///
			xtitle("Contribution", size(med)) ///
			ylabel(0(0.2)0.8, ang(0)) ///
			xlabel(0(1)10,noticks) ///
			xtick() 
		//Manually adjust the figure for aesthetics
		
*-------------------------------------------------------
*-> Figure 4 Average Profit
*-------------------------------------------------------
		use "/Users/ludong/Dropbox/TalkBehindData/data.dta", clear
		replace majority = 1 if treatment == "GMBase"
		
		collapse y = profit, by(period treat_main majority)
		
			local msize large
			local size medium
			local lwidth medium
			local color black
			local note ""
			
		twoway (connect y period if majority == 1, m(S) lcolor(`color') mcolor(`color') lpattern(solid) msize(`msize') lwidth(`lwidth') )	///
				(connect y period if majority == 0, m(Th) lcolor(`color') mcolor(`color') lpattern(dash) msize(`msize') lwidth(`lwidth') )	///
				, by(treat_main, note("") col(4)) caption(`caption1', size(`size1') pos(6)) note(`note',ring(0) pos(12) nobox) name(g1,replace)   ///
				xtitle("Round", size(`size')) ytitle("Average Profit", size(`size'))  ///
				xlabel(1(1)8, labsize(`size') ) ylabel(0(4)24, labsize(`size') angle(0)) ///
				legend(lab(1 "Partners") lab(2 "Lone Persons") size(`size') ///
				col(2) ring(0) pos(3) region(lcolor(none) fcolor(none))) scheme(s1mono) ysize(2.5)
		//Manually adjust the figure for aesthetics
				
				
		
		
*########################################################		
*########################################################	
*########################################################	
				
*-------------------------------------------------------------------------------
*-> Table 2: Random Effects Model on the Share Allocated to the Partner
*-------------------------------------------------------------------------------

		use "/Users/ludong/Dropbox/TalkBehindData/data.dta", clear	
		xtset pid period
		keep if majority == 1
		
		gen EtaXPartner = eta_i*majority
		gen a = 1 - x_i
		gen b = 1 - eta_i
		
		gen y = x_i
		gen x = eta_i
		
		tab treatment, gen(treat0)
		gen xNoCom = x*treat03
		gen xPrivCom = x*treat04
		gen xPubReadOnly = x*treat05
		gen xAllChanCom = x*treat01
		
		
		qui xtreg y x if treatment == "NoCom", cluster(mgroup)
			est store a1
			test (_b[x]= 1)  (_b[_cons] = 0 )

		qui xtreg y x if treatment == "PrivCom", cluster(mgroup)
			est store a2
			test (_b[x]= 1)  (_b[_cons] = 0 )
			
		qui xtreg y x if treatment == "PubReadOnly", cluster(mgroup)
			est store a3
			test (_b[x]= 1)  (_b[_cons] = 0 )
	
		qui xtreg y x if treatment == "AllChanCom", cluster(mgroup)
			est store a4
			test (_b[x]= 1)  (_b[_cons] = 0 )	
		
		qui xtreg y x xPrivCom xPubReadOnly xAllChanCom treat04 treat05 treat01 ///
		if treatment == "NoCom" | treatment == "PrivCom"|treatment == "PubReadOnly" | treatment == "AllChanCom", cluster(mgroup)
			est store a5
			
 
		
		esttab a1 a2 a3 a4 a5, b(%6.3f) se star(* 0.10 ** 0.05 *** 0.01)



*-------------------------------------------------------------------------------
*-> Table 3: Share received in the last round and the one round change in loner's investment
*-------------------------------------------------------------------------------

		use "/Users/ludong/Dropbox/TalkBehindData/data.dta", clear
		tab treatment
		replace partner = 0 if treatment == "GMBase"
		
		gen var1 = SumC - contribution if type == 1
		gen var2 = SumC - contribution if type == 2
		gen var3 = SumC - contribution if type == 3
		bys session group: egen base1 = max(var1)
		bys session group: egen base2 = max(var2)
		bys session group: egen base3 = max(var3)
		
		gen eta1 = contribution/base1 if type != 1
		gen eta2 = contribution/base2 if type != 2
		gen eta3 = contribution/base3 if type != 3
		gen temp1 = all12 if type == 2
		replace temp1 = all13 if type == 3
		gen temp2 = all21 if type == 1
		replace temp2 = all23 if type == 3
		gen temp3 = all31 if type == 1
		replace temp3 = all32 if type == 2
		
		gen x1 = temp1/onethirdvalue
		gen x2 = temp2/onethirdvalue
		gen x3 = temp3/onethirdvalue

		sort session group period type 
		br treatment session period group type contribution SumC eta_i eta1 x1 eta2 x2 eta3 x3 
		gen Aprop = (x1 > eta1 - 0.05 & x1 < eta1 + 0.05) if type != 1
		gen Anothing = (x1 == 0 & eta1 != 0) if type != 1
		gen Aprop_up = (x1 >= eta1 + 0.05) if type != 1
		gen Aprop_low = (x1 <= eta1 - 0.05 & Anothing != 1) if type != 1
		gen Bprop = (x2 > eta2 - 0.05 & x2 < eta2 + 0.05) if type != 2
		gen Bnothing = (x2 == 0 & eta2 != 0) if type != 2
		gen Bprop_up = (x2 >= eta2 + 0.05) if type != 2
		gen Bprop_low = (x2 <= eta2 - 0.05 & Bnothing != 1) if type != 2
		gen Cprop = (x3 > eta3 - 0.05 & x3 < eta3 + 0.05) if type != 3
		gen Cnothing = (x3 == 0 & eta3 != 0) if type != 3
		gen Cprop_up = (x3 >= eta3 + 0.05) if type != 3
		gen Cprop_low = (x3 <= eta3 - 0.05 & Cnothing != 1) if type != 3

		gen etaC = (eta1 + eta2)/3
		gen xC = (x1 + x2)/3
		
		gen Cget0 = (etaC != 0 & xC == 0) if type == 3
		gen CgetProp = (xC > etaC - 0.05 & xC < etaC + 0.05) if type == 3
		gen CgetProp_low = (xC <= etaC - 0.05 & Cget0 != 1) if type == 3
		gen CgetProp_up = (xC >= etaC + 0.05) if type == 3
		
	
		replace Aprop = . if SumC == 0
		replace Anothing = . if SumC == 0
		replace Aprop_up = . if SumC == 0
		replace Aprop_low = . if SumC == 0
		replace Bprop = . if SumC == 0
		replace Bnothing = . if SumC == 0
		replace Bprop_up = . if SumC == 0
		replace Bprop_low = . if SumC == 0
		replace Cprop = . if SumC == 0
		replace Cnothing = . if SumC == 0
		replace Cprop_up = . if SumC == 0
		replace Cprop_low = . if SumC == 0
		replace Cget0 = . if SumC == 0
		replace CgetProp_low = . if SumC == 0
		replace CgetProp_up = . if SumC == 0
		
		gen partnerGiveNothing = Anothing if type == 2
		replace partnerGiveNothing = Bnothing if type == 1
		gen partnerGiveprop = Aprop if type == 2
		replace partnerGiveprop = Bprop if type == 1
		gen partnerGiveProp_up = Aprop_up if type == 2
		replace partnerGiveProp_up = Bprop_up if type == 1
		gen partnerGiveProp_low = Aprop_low if type == 2
		replace partnerGiveProp_low = Bprop_low if type == 1
		
		gen partnerGiveProp_less = partnerGiveNothing + partnerGiveProp_low
		gen Cprop_less = Cnothing + Cprop_low
		
		
		br treatment session period group type contribution ///
			Aprop Anothing Bprop_up Bprop_low partnerGiveNothing partnerGiveProp* if type != 3
		xtset pid period
		br treatment session period group type contribution 
		gen Fcont = f.contribution
		gen dcont = Fcont - contribution
		drop if dcont == .
		
		
		xtreg dcont Cget0 CgetProp_low CgetProp_up if type == 3 & treatment == "NoCom", cluster(mgroup)
			est store a0
		xtreg dcont Cget0 CgetProp_low CgetProp_up if type == 3 & treatment == "PrivCom", cluster(mgroup)
			est store a1	
		xtreg dcont Cget0 CgetProp_low CgetProp_up if type == 3 & treatment == "PubReadOnly", cluster(mgroup)
			est store a3
		xtreg dcont Cget0 CgetProp_low CgetProp_up if type == 3 & treatment == "AllChanCom", cluster(mgroup)
			est store a4
			
		esttab a0 a1 a3 a4, b(%6.3f) se star(* 0.10 ** 0.05 *** 0.01)


*-------------------------------------------------------------------------------
*-> Table 4: Investments and returns
*-------------------------------------------------------------------------------

		use "/Users/ludong/Dropbox/TalkBehindData/data.dta", clear
		keep if treatment == "AllChanCom" | treatment == "PrivCom" ///
		| treatment == "PubReadOnly" | treatment == "NoCom"
		gen temp1 = all21 + all31 if type == 1
		replace temp1 = all12 + all32 if type == 2
		replace temp1 = all13 + all23 if type == 3
		
		gen posReturn = (temp1 - contribution > 0)
		gen negReturn = (temp1 - contribution < 0)
		//column 1
		//dividing the third column to the fourth column of the displayed result
		tab treat_main posReturn if partner == 1 
		//column 2
		tab treatment posReturn if partner == 0
		//column 3
		tab treat_main negReturn if partner == 1
		//column 4
		tab treat_main negReturn if partner == 0
		
		
	
